AbstractRPCCompleter class abstract

Implementers

Constructors

AbstractRPCCompleter(FuturesTable futuresTableInHandler, FutureUniqueIdentifier uniqueIdentifier)

Properties

futuresTableInHandler ↔ FuturesTable
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueIdentifier ↔ FutureUniqueIdentifier
getter/setter pair

Methods

getResponseUntyped() → Future<DataPackage?>
getUniqueIdentifier() → FutureUniqueIdentifier
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFailed() → void
setResponse(DataPackage responsePackage) → void
toString() → String
A string representation of this object.
inherited
wasExecutedSuccessfully() → bool

Operators

operator ==(Object other) → bool
The equality operator.
inherited