FuturesTable class

Constructors

FuturesTable()

Properties

futures ↔ Map<FutureUniqueIdentifier, AbstractRPCCompleter>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addFuture(AbstractRPCCompleter future) → void
lookupFuture(FutureUniqueIdentifier uniqueIdentifier) → AbstractRPCCompleter?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printFutures() → void
removeFuture(AbstractRPCCompleter future) → bool
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited