RPCCompleter<T> class

Inheritance

Constructors

RPCCompleter(FuturesTable futuresTableInHandler, FutureUniqueIdentifier uniqueIdentifier, T _returnTypeExample)

Properties

futuresTableInHandler ↔ FuturesTable
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueIdentifier ↔ FutureUniqueIdentifier
getter/setter pairinherited

Methods

getResponse() → Future<T?>
getResponseUntyped() → Future<DataPackage?>
inherited
getUniqueIdentifier() → FutureUniqueIdentifier
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFailed() → void
inherited
setResponse(DataPackage responsePackage) → void
inherited
toString() → String
A string representation of this object.
inherited
wasExecutedSuccessfully() → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited