RemoteFunction<T> class

Implementers

Constructors

RemoteFunction(FutureHandler _futuresHandler, StreamController<DataPackage> _outputController, RemoteFunctionIdentifier _remoteFunctionIdentifier, T _returnType, List _parameterTypes)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successful ↔ bool
getter/setter pair

Methods

executeWithParameters(List parameters) → Future<T?>
getFunctionSignature() → String
makeRemoteFunctionRequest(String futureIdentifier, List parameters) → RemoteFunctionRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited