RemoteFunctionWith3Parameters<T> class

Inheritance

Constructors

RemoteFunctionWith3Parameters(FutureHandler futuresHandler, StreamController<DataPackage> outputController, RemoteFunctionIdentifier remoteFunctionIdentifier, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successful ↔ bool
getter/setter pairinherited

Methods

execute(dynamic parameter1, dynamic parameter2, dynamic parameter3) → Future<T?>
executeWithParameters(List parameters) → Future<T?>
inherited
getFunctionSignature() → String
inherited
makeRemoteFunctionRequest(String futureIdentifier, List parameters) → RemoteFunctionRequest
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited