RemoteFunctionHandler class

Constructors

RemoteFunctionHandler(StreamController<DataPackage> _outputController)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleResponse(DataPackage remoteFunctionResponse) → void
makeRemoteModuleFunctionIdentifier(String moduleId, String functionName) → RemoteFunctionIdentifier
makeRemoteRuntimeFunctionIdentifier(Runtime runtime, String functionName) → RemoteFunctionIdentifier
mapModuleFunction<T>(String targetModule, String functionName, T returnType, List parameterDataTypes) → RemoteFunction<T>
mapModuleFunctionWith1Parameter<T>(String targetModule, String functionName, T returnType, dynamic parameter1) → RemoteFunctionWith1Parameter<T>
mapModuleFunctionWith2Parameters<T>(String targetModule, String functionName, T returnType, dynamic parameter1, dynamic parameter2) → RemoteFunctionWith2Parameters<T>
mapModuleFunctionWith3Parameters<T>(String targetModule, String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3) → RemoteFunctionWith3Parameters<T>
mapModuleFunctionWith4Parameters<T>(String targetModule, String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4) → RemoteFunctionWith4Parameters<T>
mapModuleFunctionWith5Parameters<T>(String targetModule, String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4, dynamic parameter5) → RemoteFunctionWith5Parameters<T>
mapModuleFunctionWith6Parameters<T>(String targetModule, String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4, dynamic parameter5, dynamic parameter6) → RemoteFunctionWith6Parameters<T>
mapModuleFunctionWithNParameters<T>(String targetModule, String functionName, T returnType, List parameterDataTypes) → RemoteFunction<T>
mapModuleFunctionWithoutParameter<T>(String targetModule, String functionName, T returnType) → RemoteFunctionWithoutParameter<T>
mapRuntimeFunction<T>(Runtime runtime, String functionName, T returnType, List parameterDataTypes) → RemoteFunction<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited