ClaidServiceBase class abstract

Annotations
  • @GrpcServiceName.new('claidservice.ClaidService')

Constructors

ClaidServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getModuleList(ServiceCall call, ModuleListRequest request) → Future<ModuleListResponse>
getModuleList_Pre(ServiceCall call, Future<ModuleListRequest> request) → Future<ModuleListResponse>
initRuntime(ServiceCall call, InitRuntimeRequest request) → Future<Empty>
initRuntime_Pre(ServiceCall call, Future<InitRuntimeRequest> request) → Future<Empty>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendReceivePackages(ServiceCall call, Stream<DataPackage> request) → Stream<DataPackage>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited