LayerDataType class

Inheritance
  • Object
  • ProtobufEnum
  • LayerDataType

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

valueOf(int value) → LayerDataType?

Constants

FLOAT32 → const LayerDataType
INT8 → const LayerDataType
INT16 → const LayerDataType
INT32 → const LayerDataType
UINT8 → const LayerDataType
UINT16 → const LayerDataType
UINT32 → const LayerDataType
values → const List<LayerDataType>