MockChannel<T> class

Constructors

MockChannel({required String id, required String sourceModule, required String targetModule, MockGenerator<T>? generator, int startMs = 0, int periodMs = 1000, int count = 10})

Properties

count → int
final
generator ↔ MockGenerator<T>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
periodMs → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceModule → String
final
startMs → int
final
targetModule → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited