MockModuleEnv class

Constructors

MockModuleEnv({required List<EnvModule> modules, required List<MockChannel> channels})

Properties

allFactories → Map<String, FactoryFunc>
no setter
channels → List<MockChannel>
final
hashCode → int
The hash code for this object.
no setterinherited
moduleDescriptors → List<ModDescriptor>
no setter
modules → List<EnvModule>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

combinedFactories(Map<String, FactoryFunc> underTest) → Map<String, FactoryFunc>
getEventsForChannel(String channelId) → List<DataPackage>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited