UnderTest class

Implemented types

Constructors

UnderTest({dynamic id, required dynamic moduleClass, required dynamic properties})

Properties

descriptor → ModDescriptor
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
finalinherited
moduleClass → String?
finalinherited
properties → Struct?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited