Channel<T> class

Constructors

Channel(String _moduleId, String _channelId, Mutator<T> _mutator, ModuleManager _manager, ChannelAccessRights _accessRights, ChannelCallback<T>? _callback)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMessageReceived(DataPackage pkt) → void
post(T payload) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited