ModuleManager class

Constructors

ModuleManager(ModuleDispatcher dispatcher, Map<String, FactoryFunc> factories)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getInstanceForChannel(String channelId) → dynamic
getModule(String moduleId) → Module?
getPublishChannel<T>(String moduleId, String channelId, T inst) → Channel<T>
getRemoteFunctionHandler() → RemoteFunctionHandler
getSubscribeChannel<T>(String moduleId, String channelId, T inst, ChannelCallback<T> callback) → Channel<T>
lifecycle(String moduleId) → Lifecycle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(DataPackage pkt) → Future<void>
registerDataReceiverEntity(String entityName, ReceiverFunc dataReceiverFunc) → bool
start() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ModuleManager
no setter