EmptyDefaultDeviceView class

Inheritance

Constructors

EmptyDefaultDeviceView(String entityName, String mappedModuleId, String moduleClass, ModuleManager moduleManager, {Key? key})

Properties

entityName → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
imagePath ↔ String
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mappedModuleId → String
finalinherited
moduleClass → String
finalinherited
remoteFunctionHandler ↔ RemoteFunctionHandler?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<EmptyDefaultDeviceView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getImage(BuildContext context) → Widget
override
getModuleSubType() → String
override
getModuleType() → String
override
getName() → String
override
getSubCaptionWidget() → Widget
override
mapFunction<T>(String functionName, T returnType, List parameters) → RemoteFunction<T>
inherited
mapMiddlewareFunction<T>(String functionName, T returnType, List parameters) → RemoteFunction<T>
inherited
mapModuleFunctionWith1Parameter<T>(String functionName, T returnType, dynamic parameter1) → RemoteFunctionWith1Parameter<T>
inherited
mapModuleFunctionWith2Parameters<T>(String functionName, T returnType, dynamic parameter1, dynamic parameter2) → RemoteFunctionWith2Parameters<T>
inherited
mapModuleFunctionWith3Parameters<T>(String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3) → RemoteFunctionWith3Parameters<T>
inherited
mapModuleFunctionWith4Parameters<T>(String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4) → RemoteFunctionWith4Parameters<T>
inherited
mapModuleFunctionWith5Parameters<T>(String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4, dynamic parameter5) → RemoteFunctionWith5Parameters<T>
inherited
mapModuleFunctionWith6Parameters<T>(String functionName, T returnType, dynamic parameter1, dynamic parameter2, dynamic parameter3, dynamic parameter4, dynamic parameter5, dynamic parameter6) → RemoteFunctionWith6Parameters<T>
inherited
mapModuleFunctionWithoutParameter<T>(String functionName, T returnType) → RemoteFunctionWithoutParameter<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataFromLooseDirectSubscription(DataPackage package) → void
inherited
onHidden() → void
inherited
onShown() → void
inherited
subscribeModuleChannel<T>(String channelName, T dataType, DataReceiverCallback<T> callback) → Future<bool?>
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited