MappedModule class abstract

Constructors

MappedModule(String entityName, String mappedModuleId, String moduleClass, ModuleManager moduleManager)

Properties

entityName → String
final
hashCode → int
The hash code for this object.
no setterinherited
mappedModuleId → String
final
moduleClass → String
final
remoteFunctionHandler ↔ RemoteFunctionHandler?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

mapFunction<T>(String functionName, T returnType, List parameters) → RemoteFunction<T>
mapMiddlewareFunction<T>(String functionName, T returnType, List parameters) → RemoteFunction<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDataFromLooseDirectSubscription(DataPackage package) → void
subscribeModuleChannel<T>(String channelName, T dataType, DataReceiverCallback<T> callback) → Future<bool?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited